[flashrom] [PATCH] Board enable for HP Vectra VL420SFF

Michael Karcher flashrom at mkarcher.dialup.fu-berlin.de
Fri Feb 12 17:09:59 CET 2010


This code has been tested by Mattias Mattsson on 23. December 2009,
but without the DMI match. Now that DMI support is in and working,
the board can be added to mainline flashrom.

Signed-off-by: Michael Karcher <flashrom at mkarcher.dialup.fu-berlin.de>
---
Hello Mattias, could you please try whether current svn flashrom (at least
r896) with this patch applied outputs
 Disabling write protection for HP VL420 SFF
on invocation with "flashrom -V"? If yes, please reply to this mail with a
mail containing the line "Acked-by: Mattias Mattsson <vitplister at gmail.com>".
You don't have to try anything dangerous like erasing/writing the flash
chip, as only the board recognition has changed.

Regards,
  Michael Karcher

 board_enable.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)

diff --git a/board_enable.c b/board_enable.c
index 2de5fd7..2aa9c10 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -869,7 +869,9 @@ static int intel_ich_gpio21_raise(const char *name)
 }
 
 /**
  * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
  */
 static int intel_ich_gpio22_raise(const char *name)
 {
@@ -1224,6 +1226,7 @@ struct board_pciid_enable board_pciid_enables[] = {
 	{0x1002, 0x4398, 0x1458, 0x5004,  0x1002, 0x4391, 0x1458, 0xb002, NULL,          NULL,         NULL,          "GIGABYTE",    "GA-MA78GM-S2H",         0,   it87xx_probe_spi_flash},
 	{0x1002, 0x438d, 0x1458, 0x5001,  0x1002, 0x5956, 0x1002, 0x5956, NULL,          NULL,         NULL,          "GIGABYTE",    "GA-MA790FX-DQ6",        0,   it87xx_probe_spi_flash},
 	{0x1166, 0x0223, 0x103c, 0x320d,  0x102b, 0x0522, 0x103c, 0x31fa, NULL,          "hp",         "dl145_g3",    "HP",          "DL145 G3",              0,   board_hp_dl145_g3_enable},
+	{0x8086, 0x1a30, 0x103c, 0x1a30,  0x8086, 0x2443, 0x103c, 0x2440, "^VL420$",     NULL,         NULL,          "HP",          "VL420 SFF",             0,   intel_ich_gpio22_raise},
 	{0x1166, 0x0205, 0x1014, 0x0347,  0x1002, 0x515E, 0x1014, 0x0325, NULL,          NULL,         NULL,          "IBM",         "x3455",                 0,   board_ibm_x3455},
 	{0x1039, 0x5513, 0x8086, 0xd61f,  0x1039, 0x6330, 0x8086, 0xd61f, NULL,          NULL,         NULL,          "Intel",       "D201GLY",               0,   wbsio_check_for_spi},
 	{0x1022, 0x7468,      0,      0,       0,      0,      0,      0, NULL,          "iwill",      "dk8_htx",     "IWILL",       "DK8-HTX",               0,   w83627hf_gpio24_raise_2e},
@@ -869,7 +869,9 @@ static int intel_ich_gpio21_raise(const char *name)
 
 /**
- * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
+ * Suited for:
+ *  - Asus P4B266: socket478 + intel 845D + ICH2.
+ *  - Asus P4B-MX variant in HP Vectra VL420 SFF: socket478 + 845D + ICH2
  */
 static int intel_ich_gpio22_raise(const char *name)
-- 
1.6.5





More information about the flashrom mailing list